@@ -14,6 +14,8 @@ import inspect
 from inspect import signature
 from urllib.parse import urlparse
 import ast
+from datetime import datetime
+# os.environ["PYTHONWARNINGS"] = 'ignore'
 
 logging.basicConfig(format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
                     level=logging.INFO)
@@ -1838,3 +1840,101 @@ class DataPlate:
         except Exception as e:
             logging.exception('Could not find relevant endpoint')
 
+
+    def save_statistic(self, variable_name, variable_value):
+        """ Save a statistics to follow later - can big a matplotlib-figure/dataframe/string/dict/json/int/float
+            You can later call the report_statistic API to get a list of all statistics of last X runs
+        Args:
+            variable_name (str): The name for the statistics
+            variable_value : can be any value or type matplotlib-figure/dataframe/string/dict/json/int/float
+        """
+        try:
+            import scrapbook as sb
+            from IPython.display import clear_output
+            clear_output()
+            if not variable_name:
+                logging.exception('Could not save statistic: make sure variable_name and variable_value are defined')
+            if str(type(variable_value)) == "<class 'matplotlib.figure.Figure'>":
+                logging.info(f'found Figure type')
+                sb.glue(variable_name, variable_value, 'display')
+            elif str(type(variable_value)) == "<class 'pandas.core.frame.DataFrame'>":
+                logging.info(f'found DataFrame type')
+                sb.glue(variable_name, variable_value, 'pandas')
+            else:
+                sb.glue(variable_name, variable_value)
+
+            logging.info(f'statistics {variable_name} saved successfully')
+        except Exception as e:
+            logging.exception('Could not save statistic: make sure the variable_value is either: dataframe/string/dict/json/int/float/matplotlib-figure')
+
+
+    def report_statistic(self, notebook_name, number_runs=5, include_data=False, embed_report=True):
+        """ Report a statistics that was saved using the save_statistic API
+            Get a list of all statistics of last X runs
+        Args:
+            notebook_name (str): The name for the notebook to get the last statistics report for
+            number_runs (int): number of last X runs to show statistics report for (default=5)
+            include_data (bool): should include dataFrames or other data. By default includes only figures (default=False)
+            embed_report (bool): display report as iFrame inside the notebook (default=True)
+        """
+        # deleteHtmlResult (bool): delete the html output local report (default=False)
+        try:
+            headers = {'X-Access-Key': self.access_key, 'Content-Type': 'application/json'}
+
+            if not notebook_name or len(notebook_name) == 0:
+                raise FileNotFoundError(
+                    f'notebook_name is not legal/valid : {notebook_name if notebook_name else "None"}')
+
+            params = {}
+            params['notebook_name'] = notebook_name
+            params['number_runs'] = number_runs
+            params['include_data'] = include_data
+
+            logging.info('sending report request...')
+            r = self.session.post( \
+                '{}/api/aws/reportNotebookStatistics'.format(self.base_url), params=params, data=json.dumps('{}'),
+                headers=headers, stream=True, allow_redirects=False)
+
+            if r.status_code != 200:
+                if r.status_code == 302:
+                    raise Error(
+                        'Bad Access Key! Get your access key at: {}'.format(
+                            self.base_url))
+                if r.status_code == 206:
+                    logging.info('scanning notebook, processing...')
+                    time.sleep(5)
+                raise Error(
+                    'Bad HTTP exit status returned from the API: {}. Error was: {}'.
+                        format(r.status_code, r.text))
+
+            logging.info('Parsing response')
+            # logging.info(str(r.text))
+            if r.text:
+                output_read_path = r.text
+                if output_read_path:
+                    str_report_name = "html_report_" + str(datetime.now())[:19].strip() + ".html"
+                    with open(str_report_name, "w") as f:
+                        f.write(output_read_path)
+
+                    logging.info('report statistics retrieved successfully.')
+                    output = f'%%html\n<iframe src="{str_report_name}" width="100%" height="1200"></iframe>'
+                    if embed_report:
+                        import IPython
+                        IPython.get_ipython().run_cell(output)
+                    # if deleteHtmlResult:
+                    #     os.remove(str_report_name)
+                    return str_report_name
+                else:
+                    logging.exception('Could not get statistics report properly - please check your s3 connection')
+            else:
+                logging.exception('Could not find proper output, please check your parameters')
+            # return r.text
+
+        except (requests.exceptions.ConnectionError,
+                requests.exceptions.ReadTimeout) as e:
+            logging.exception('Got ConnectionError/ReadTimeout exception.')
+            raise Error(e)
+
+        except Exception as e:
+            logging.exception('scan_notebook , ' + str(e))
+            raise Error(e)
\ No newline at end of file
